## Installation

```bash
pip install mqss-client
```

## Usage

```python
from mqss_client import MQSSClient

URL = "<mqp-api-url>"
TOKEN = "<your-mqp-token>"

# create a client instance
client = MQSSClient(token=TOKEN, url=URL)
```

## Changelog

See the [CHANGELOG](CHANGELOG.md) for details on changes in each version.
